==> freecad_0.11.4446-dfsg.orig.tar.gz: FreeCAD-0.11.4446/src/Mod/Raytracing/Gui/Resources/translations/Raytracing_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdRaytracingExportProject</name>
    <message>
      <location/>
      <source>File</source>
      <translation>Datoteka</translation>
    </message>
    <message>
      <location/>
      <source>&amp;Export project...</source>
      <translation>&amp;Izvezi projekt...</translation>
    </message>
    <message>
      <location/>
      <source>Export the Povray project file</source>
      <translation>Izvoz datoteka Povray projekt</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewPartSegment</name>
    <message>
      <location/>
      <source>Raytracing</source>
      <translation>Metode trasiranja putem zrake</translation>
    </message>
    <message>
      <location/>
      <source>Insert part</source>
      <translation>Umetni dio</translation>
    </message>
    <message>
      <location/>
      <source>Insert a new part object into a Povray project</source>
      <translation>Umetnite novi dio objekta u Povray-projekta</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewPovrayProject</name>
    <message>
      <location/>
      <source>Raytracing</source>
      <translation>Metode trasiranja putem zrake</translation>
    </message>
    <message>
      <location/>
      <source>New Povray project</source>
      <translation>Novi projekt Povray</translation>
    </message>
    <message>
      <location/>
      <source>Insert new Povray project into the document</source>
      <translation>Umetanje novog Povray projekta u dokument</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewProject</name>
    <message>
      <location/>
      <source>Raytracing</source>
      <translation>Metode trasiranja putem zrake</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingQuickRender</name>
    <message>
      <location/>
      <source>Raytracing</source>
      <translation>Metode trasiranja putem zrake</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWriteCamera</name>
    <message>
      <location/>
      <source>Raytracing</source>
      <translation>Metode trasiranja putem zrake</translation>
    </message>
    <message>
      <location/>
      <source>Export camera to povray</source>
      <translation>Prenesi fotoaparat na povray</translation>
    </message>
    <message>
      <location/>
      <source>Export the camera positon of the active 3D view in PovRay format to a file</source>
      <translation>Prenesi položaj kamere iz  3D aktivnog prikaza u povray format, u datoteku</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWritePart</name>
    <message>
      <location/>
      <source>Raytracing</source>
      <translation>Metode trasiranja putem zrake</translation>
    </message>
    <message>
      <location/>
      <source>Export part to povray...</source>
      <translation>Izvoz dijela u povray ...</translation>
    </message>
    <message>
      <location/>
      <source>Write the selected Part (object) as a povray file</source>
      <translation>Napišite odabrani dio (objekta) kao povray datoteke</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWriteView</name>
    <message>
      <location/>
      <source>Raytracing</source>
      <translation>Metode trasiranja putem zrake</translation>
    </message>
    <message>
      <location/>
      <source>Export view to povray...</source>
      <translation>Pogled u povray ...</translation>
    </message>
    <message>
      <location/>
      <source>Write the active 3D view with camera and all its content to a povray file</source>
      <translation>Napišite aktivni 3D prikaz s kamerom i sve njezine sadržaje u povray datoteke</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location/>
      <source>Povray(*.pov)</source>
      <translation>Povray (*. pov)</translation>
    </message>
    <message>
      <location/>
      <source>All Files (*.*)</source>
      <translation>Sve datoteke (*.*)</translation>
    </message>
    <message>
      <location/>
      <source>Export page</source>
      <translation>Izvezi stranicu</translation>
    </message>
    <message>
      <location/>
      <source>Wrong selection</source>
      <translation>Pogrešan odabir</translation>
    </message>
    <message>
      <location/>
      <source>Select a Part object.</source>
      <translation>Odaberite dio objekta.</translation>
    </message>
    <message>
      <location/>
      <source>No Povray project to insert</source>
      <translation>Nema Povray projekta za umetanje</translation>
    </message>
    <message>
      <location/>
      <source>Create a Povray project to insert a view.</source>
      <translation>Napravite Povray projekt za umetanje pogleda.</translation>
    </message>
    <message>
      <location/>
      <source>Select one Povray project object.</source>
      <translation>Odaberite jedan objekt Povray projekta.</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::DlgSettingsRay</name>
    <message>
      <location/>
      <source>Raytracing</source>
      <translation>Metode trasiranja putem zrake</translation>
    </message>
    <message>
      <location/>
      <source>Directories</source>
      <translation>Mape</translation>
    </message>
    <message>
      <location/>
      <source>Default Project dir:</source>
      <translation>Osnovni Projekt dir:</translation>
    </message>
    <message>
      <location/>
      <source>Camera file name:</source>
      <translation>Kamera, ime datoteke:</translation>
    </message>
    <message>
      <location/>
      <source>Part file name:</source>
      <translation>Dio naziva datoteke:</translation>
    </message>
    <message>
      <location/>
      <source>TempCamera.inc</source>
      <translation>TempCamera.inc</translation>
    </message>
    <message>
      <location/>
      <source>TempPart.inc</source>
      <translation>TempPart.inc</translation>
    </message>
    <message>
      <location/>
      <source>Mesh export settings</source>
      <translation>Izvoz postavki mreže</translation>
    </message>
    <message>
      <location/>
      <source>max mesh deviation:</source>
      <translation>max devijacija mreže:</translation>
    </message>
    <message>
      <location/>
      <source>Do not calculate vertex normals</source>
      <translation>Ne izračunati vrh normale </translation>
    </message>
    <message>
      <location/>
      <source>Write u,v coordinates</source>
      <translation>Napišite u,v koordinate</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::Workbench</name>
    <message>
      <location/>
      <source>&amp;Raytracing</source>
      <translation>Metode trasiranja putem zrake</translation>
    </message>
  </context>
</TS>

==> freecad_0.12.5284-dfsg.orig.tar.gz: FreeCAD-0.12.5284/src/Mod/Raytracing/Gui/Resources/translations/Raytracing_hr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdRaytracingExportProject</name>
    <message>
      <location filename="../../Command.cpp" line="+452"/>
      <source>File</source>
      <translation>Datoteka</translation>
    </message>
    <message>
      <source>&amp;Export project...</source>
      <translation>&amp;Izvezi projekt...</translation>
    </message>
    <message>
      <source>Export the Povray project file</source>
      <translation>Izvoz datoteka Povray projekt</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewPartSegment</name>
    <message>
      <source>Raytracing</source>
      <translation>Metode trasiranja putem zrake</translation>
    </message>
    <message>
      <source>Insert part</source>
      <translation>Umetni dio</translation>
    </message>
    <message>
      <source>Insert a new part object into a Povray project</source>
      <translation>Umetnite novi dio objekta u Povray-projekta</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingNewPovrayProject</name>
    <message>
      <source>Raytracing</source>
      <translation>Metode trasiranja putem zrake</translation>
    </message>
    <message>
      <source>New Povray project</source>
      <translation>Novi projekt Povray</translation>
    </message>
    <message>
      <source>Insert new Povray project into the document</source>
      <translation>Umetanje novog Povray projekta u dokument</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWriteCamera</name>
    <message>
      <source>Raytracing</source>
      <translation>Metode trasiranja putem zrake</translation>
    </message>
    <message>
      <source>Export camera to povray...</source>
      <translation>Izvoz kamere u povray ...</translation>
    </message>
    <message>
      <source>Export the camera positon of the active 3D view in PovRay format to a file</source>
      <translation>Prenesi položaj kamere iz  3D aktivnog prikaza u povray format, u datoteku</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWritePart</name>
    <message>
      <source>Raytracing</source>
      <translation>Metode trasiranja putem zrake</translation>
    </message>
    <message>
      <source>Export part to povray...</source>
      <translation>Izvoz dijela u povray ...</translation>
    </message>
    <message>
      <source>Write the selected Part (object) as a povray file</source>
      <translation>Napišite odabrani dio (objekta) kao povray datoteke</translation>
    </message>
  </context>
  <context>
    <name>CmdRaytracingWriteView</name>
    <message>
      <source>Raytracing</source>
      <translation>Metode trasiranja putem zrake</translation>
    </message>
    <message>
      <source>Export view to povray...</source>
      <translation>Pogled u povray ...</translation>
    </message>
    <message>
      <source>Write the active 3D view with camera and all its content to a povray file</source>
      <translation>Napišite aktivni 3D prikaz s kamerom i sve njezine sadržaje u povray datoteke</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Povray(*.pov)</source>
      <translation>Povray (*. pov)</translation>
    </message>
    <message>
      <source>All Files (*.*)</source>
      <translation>Sve datoteke (*.*)</translation>
    </message>
    <message>
      <source>Export page</source>
      <translation>Izvezi stranicu</translation>
    </message>
    <message>
      <source>Wrong selection</source>
      <translation>Pogrešan odabir</translation>
    </message>
    <message>
      <source>Select a Part object.</source>
      <translation>Odaberite dio objekta.</translation>
    </message>
    <message>
      <source>No Povray project to insert</source>
      <translation>Nema Povray projekta za umetanje</translation>
    </message>
    <message>
      <source>Create a Povray project to insert a view.</source>
      <translation>Napravite Povray projekt za umetanje pogleda.</translation>
    </message>
    <message>
      <source>Select one Povray project object.</source>
      <translation>Odaberite jedan objekt Povray projekta.</translation>
    </message>
  </context>
  <context>
    <name>RaytracingGui::DlgSettingsRay</name>
    <message>
      <location filename="../../DlgSettingsRay.ui" line="+16"/>
      <source>Raytracing</source>
      <translation>Metode trasiranja putem zrake</translation>
    </message>
    <message>
      <source>Directories</source>
      <translation>Mape</translation>
    </message>
    <message>
      <source>Default Project dir:</source>
      <translation>Osnovni Projekt dir:</translation>
    </message>
    <message>
      <source>Camera file name:</source>
      <translation>Kamera, ime datoteke:</translation>
    </message>
    <message>
      <source>Part file name:</source>
      <translation>Dio naziva datoteke:</translation>
    </message>
    <message>
      <source>TempCamera.inc</source>
      <translation>TempCamera.inc</translation>
    </message>
    <message>
      <source>TempPart.inc</source>
      <translation>TempPart.inc</translation>
    </message>
    <message>
      <source>Mesh export settings</source>
      <translation>Izvoz postavki mreže</translation>
    </message>
    <message>
      <source>max mesh deviation:</source>
      <translation>max devijacija mreže:</translation>
    </message>
    <message>
      <source>Do not calculate vertex normals</source>
      <translation>Ne izračunati vrh normale </translation>
    </message>
    <message>
      <source>Write u,v coordinates</source>
      <translation>Napišite u,v koordinate</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>&amp;Raytracing</source>
      <translation>Metode trasiranja putem zrake</translation>
    </message>
  </context>
</TS>
